@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: affile.c,v 1.41 2001/10/20 13:03:59 bazsi Exp $
+ * $Id: affile.c,v 1.42 2001/10/24 10:46:06 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -118,7 +118,7 @@ static int do_init_affile_source(struct log_handler *c, struct syslog_config *cf
 		struct resource_node *res;
 
 		lseek(fd, 0, SEEK_END);
-		self->src = io_read(make_io_fd(cfg->backend, fd, self->name), 
+		self->src = io_read(make_io_fd(cfg->backend, fd, ol_string_use(self->name)), 
 			make_log_reader(0, c), 
 			NULL);
 		res = REMEMBER_RESOURCE(cfg->resources, &self->src->super.super);
@@ -218,7 +218,7 @@ do_init_dest_writer(struct log_handler *c, struct syslog_config *cfg, struct per
 	                 self->owner->flags & AFFILE_CREATE_DIRS, &fd)) {
 
 		self->dest = 
-			io_write(make_io_fd(cfg->backend, fd, self->expanded_fname), 
+			io_write(make_io_fd(cfg->backend, fd, ol_string_use(self->expanded_fname)), 
 				 make_pkt_buffer_ext(self->owner->sync_freq, 
 				                     MAX(self->owner->super.log_fifo_size + 1, 
 					                 self->owner->sync_freq)),
