@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: affile.h,v 1.15 2001/03/30 15:02:31 bazsi Exp $
+ * $Id: affile.h,v 1.16 2001/08/26 15:06:25 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -45,7 +45,11 @@
 #define AFFILE_CREATE_DIRS    0x0010
 #define AFFILE_CREATE_DIRS_SHIFT 4
 
+#define AFFILE_FSYNC          0x0020
+#define AFFILE_FSYNC_SHIFT    5
+
 void affile_set_syncfreq(struct log_dest_driver *affile, int syncfreq);
+void affile_set_fsync(struct log_dest_driver *c, int enable);
 void affile_set_compress(struct log_dest_driver *affile, int enable);
 void affile_set_encrypt(struct log_dest_driver *affile, int enable);
 void affile_set_owner(struct log_dest_driver *c, char *owner);
