@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: main.c,v 1.34 2001/08/26 15:06:25 bazsi Exp $
+ * $Id: main.c,v 1.36 2001/10/26 16:08:51 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -184,6 +184,9 @@ int main_loop(struct syslog_backend *backend)
 				{ { STATIC_HEADER, do_reread_config }, NULL, 0 };
 				
 				io_callout_flush(&backend->super);
+
+				s.timeout = backend->configuration->stats_freq;
+				io_callout(&backend->super, s.timeout, &s.super);
 				
 				r.backend = backend;
 				r.state = 0;
